@@ -19,6 +19,8 @@
 #define INITLENGTH 16
 
 
+unsigned long GetWordLineNo;
+
 char * Get_Word(FILE *fp, int *WordLength,int *eofptr)
 {
   int c;
@@ -36,6 +38,7 @@ char * Get_Word(FILE *fp, int *WordLength,int *eofptr)
     c=getc(fp);
     //    if(isspace(c)) {
     if ( (c == ' ') || (c == '\t') || (c == '\n') || (c == '\r') || (c == '\f') || (c == '\v')) {
+      if (c == '\n') GetWordLineNo++;
       Word[CharsRead]='\0';
       *WordLength=CharsRead;
       return(Word);
