@@ -1,4 +1,4 @@
-/* Time-stamp: <2007-09-24 08:13:43 poser>
+/* Time-stamp: <2008-06-04 01:22:32 poser>
  *
  * This function reads from a file descriptor presumed to contain text encoded
  * in UTF-8 and returns the next UTF-32 character. It performs the same
@@ -100,8 +100,14 @@ UTF32 UTF8in (int fd, int *bytes, unsigned char **bstr)
 
   /* Get the first byte */
   BytesRead = read(fd,(void *) c,1);
-  if (BytesRead == 0) return (UTF8_ENDOFFILE);
-  if (BytesRead < 0) return (UTF8_IOERROR); 
+  if (BytesRead == 0) {
+    *bytes = 0;
+    return (UTF8_ENDOFFILE);
+  }
+  if (BytesRead < 0) {
+    *bytes = 0;
+    return (UTF8_IOERROR); 
+  }
 
   /* Now get the remaining bytes */
   BytesNeeded = (int) TrailingBytesForUTF8[c[0]];
@@ -110,7 +116,10 @@ UTF32 UTF8in (int fd, int *bytes, unsigned char **bstr)
     BytesRead = read(fd,(void *) &c[BytesSoFar+1],(size_t) (BytesNeeded-BytesSoFar));
     BytesSoFar += BytesRead;
   } while (BytesRead > 0 || BytesSoFar < BytesNeeded);
-  if(BytesSoFar != BytesNeeded) return(UTF8_NOTENOUGHBYTES);
+  if(BytesSoFar != BytesNeeded) {
+    *bytes = (BytesSoFar + 1);
+    return(UTF8_NOTENOUGHBYTES);
+  }
   *bytes = BytesNeeded+1;
   *bstr = &c[0];
 
